Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Downloader ¶
type Downloader interface {
Download(ctx context.Context, bucketName string, objectName string) (io.ReadCloser, error)
}
Downloader is an interface for downloading objects from a cloud provider.
type GenericS3Provider ¶
type GenericS3Provider struct {
// contains filtered or unexported fields
}
func NewGenericS3Provider ¶
func NewGenericS3Provider(endpoint, accessKey, secret, region string) (*GenericS3Provider, error)
func (*GenericS3Provider) Download ¶
func (s *GenericS3Provider) Download(ctx context.Context, bucketName string, objectName string) (io.ReadCloser, error)
type Provider ¶
type Provider interface {
Uploader
Downloader
}
Provider is an interface that can both upload and download objects.
Click to show internal directories.
Click to hide internal directories.